[PATCH 5/5] core: fix comments cancelation->cancellation



---
 src/grl-media-source.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/grl-media-source.c b/src/grl-media-source.c
index 0504188..b29a136 100644
--- a/src/grl-media-source.c
+++ b/src/grl-media-source.c
@@ -2171,7 +2171,7 @@ grl_media_source_cancel (GrlMediaSource *source, guint operation_id)
   }
 
   /* Mark the operation as finished, if the source does
-     not implement cancelation or it did not make it in time, we will
+     not implement cancellation or it did not make it in time, we will
      not emit the results for this operation in any case.
      At any rate, we will not free the operation data until we are sure
      the plugin won't need it any more, which it will tell when it emits
@@ -2179,7 +2179,7 @@ grl_media_source_cancel (GrlMediaSource *source, guint operation_id)
      or because it managed to cancel it and is signaling so) */
   set_operation_cancelled (source, operation_id);
 
   /* If the source provides an implementation for operacion cancelation,
      let's use that to avoid further unnecessary processing in the plugin */
   if (GRL_MEDIA_SOURCE_GET_CLASS (source)->cancel) {
     GRL_MEDIA_SOURCE_GET_CLASS (source)->cancel (source, operation_id);
@@ -2179,7 +2179,7 @@ grl_media_source_cancel (GrlMediaSource *source, guint operation_id)
   set_operation_cancelled (source, operation_id);
 
-  /* If the source provides an implementation for operacion cancelation,
+  /* If the source provides an implementation for operation cancellation,
      let's use that to avoid further unnecessary processing in the plugin */
   if (GRL_MEDIA_SOURCE_GET_CLASS (source)->cancel) {
-- 
1.7.1



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]